/**
 * @description 路由守卫，目前两种模式：all模式与intelligence模式
 */
import router from '@/router'
import store from '@/store'
import getPageTitle from '@/utils/pageTitle'
import {
    authentication,
    loginInterception,
    recordRoute,
    routesWhiteList,
} from '@/config'

router.beforeEach(async (to, from, next) => {
    let hasToken = store.getters['user/accessToken']

    if (to.path !== '/login') store.commit('getAuthorities', to.meta.title)
    if (!loginInterception) hasToken = true

    if (hasToken) {
        if (to.path === '/login') {
            next({ path: '/' })
        } else if (to.path == '/home') {
            if (window.location.host.indexOf('localhost') != -1) {
                window.location.href = "http://localhost:8081/vuefiv#/home";
            } else if (window.location.host.indexOf('pcdev.ewoogi.com') != -1) {
                window.location.href = "https://pcdev.ewoogi.com/vuefiv#/home";
            } else {
                window.location.href = "https://wx.ewoogi.com/panel/#/home";
            }
        } else {
            const hasRoles =
                store.getters['acl/admin'] ||
                store.getters['acl/role'].length > 0 ||
                store.getters['acl/ability'].length > 0

            if (hasRoles) {
                if (to.matched.length === 0) {
                    next('/404') // 判断此跳转路由的来源路由是否存在，存在的情况跳转到来源路由，否则跳转到404页面
                    return;
                }
                next()
            } else {
                try {
                    //loginInterception为false（关闭登录拦截时）时，创建虚拟角色
                    if (loginInterception) {
                        await store.dispatch('user/getUserInfo')
                    } else {
                        await store.dispatch('user/setVirtualRoles');
                    }

                    let accessRoutes = []
                    if (authentication === 'intelligence') {
                        accessRoutes = await store.dispatch('routes/setRoutes')
                    } else if (authentication === 'all') {
                        accessRoutes = await store.dispatch('routes/setAllRoutes')
                    }

                    accessRoutes.forEach((item) => {
                        if (!router.hasRoute(item.name)) { // 假设路由配置有唯一 name
                            router.addRoute(item);
                        }
                    });

                    // 确保 accessRoutes 有效且处理边界情况
                    if (accessRoutes.length > 0) {
                        // 优先使用目标路由 to，若无效则跳转到第一个有效路由
                        next({ path: to.path, replace: true });
                    } else {
                        // 无动态路由时，跳转到默认页（如首页）
                        next({ ...to, replace: true })
                    }

                } catch {
                    await store.dispatch('user/resetAll')
                    if (recordRoute)
                        next({ path: '/login', query: { redirect: to.path }, replace: true, })
                    else next({ path: '/login', replace: true })
                }
            }

            // 获取公共数据
            await store.commit("publicSiteList")
            await store.commit('publicDeviceList')
        }
    } else {
        if (routesWhiteList.indexOf(to.path) !== -1) {
            next()
        } else {
            if (recordRoute) {
                next({ path: '/login', query: { redirect: to.path }, replace: true })
            } else {
                next({ path: '/login', replace: true })
            }
        }
    }


})

router.afterEach((to) => {
    document.title = getPageTitle(to.meta.title)
})