/**
 * @description 导入所有 vuex 模块，自动加入namespaced:true，用于解决vuex命名冲突，请勿修改。
 */
import dayjs from 'dayjs';
import { createStore } from 'vuex'
import * as api from '@/api/publicList'
import ElMessage from 'element-plus'

const files = require.context('./modules', false, /\.js$/)
const modules = {}
files.keys().forEach((key) => {
    modules[key.replace(/(\.\/|\.js)/g, '')] = files(key).default
})

Object.keys(modules).forEach((key) => {
    modules[key]['namespaced'] = true
})
export default createStore({
    modules,
    state: {
        query: null,
        auth: 0,
        siteId: 1, //公共api请求参数->siteId
        siteList: [], //公共api站点下拉列表存储->siteId
        deviceList: [], //公共站点下拉列表
        monthList: [], //公共每月最后一天信息存储
        dateList: [], //公共每月当天信息存储

        authorities: [],

        timeProcessing: '',

        Time_Data: [], //公共api请求参数->Time_Data
        timearr: [], //公共处理开始时间和结束时间中的时间段天数 值存储
        Time_All: [], //公共时间 返回数组 -> 年月日时分秒 时间戳


        queryType: '', //设备监控--->数据报表api请求参数->queryType
        run_off_Status: null, //设备监控--->运行状态统计->echarts->OFF次数分布和运行状态曲线图表 api信息存储
        se_defaultTime: [], //设备监控--->历史趋势时间选择器v-model
        th_defaultTime: [], //设备监控--->数据报表时间选择器v-model
        fh_defaultTime: [], //设备监控--->运行状态统计时间选择器v-model


        // tableHeight:0,//公共table监听高度变化
        // echartHeight:0,//公共ehcarts监听高度变化


        basicInfoSiteName: '', // 站点基本信息
        basicInfoConst: 1, // 站点弹窗

        siteManageLabelCom: '', //站点管理，树结构label传值
        siteCameraTimer: '', //站点管理,摄像头定时器


        /**评估报告指标趋势**/
        realScoreLineObj: [], //图表数据
        realScoreLineObj2: [],
        realScoreLineDataTime: [], //图表时间线
        realScoreLineName: '',
        realScoreLineName2: '',
        chartType: '', //点击表格传参类型

        goUrl: 0 //立即前往变化
    },
    mutations: {
        /**
         * @公共站点下拉列表
         * @param {*} state 
         */
        async publicSiteList(state) {
            await api
                .SiteList({})
                .then((requset) => {
                    if (requset.status === 'SUCCESS') {
                        state.siteList = requset.data
                        state.siteId = requset.data[0].id
                    } else {
                        ElMessage.error(requset.msg)
                    }
                })
        },
        /**
         * @公共左侧树状设备
         * @param {*} state 
         */
        publicDeviceList(state) {
            if (state.siteId != "" && state.siteId != null) {
                api
                    .dataManagementDeviceList({ siteId: state.siteId })
                    .then((requset) => {
                        if (requset.status === 'SUCCESS') {
                            state.deviceList = []
                            requset.data.map((val) => {
                                // if (val.children.length > 0) {
                                state.deviceList.push({
                                    deviceCode: val.deviceCode,
                                    deviceName: val.deviceName,
                                    id: val.id,
                                    children: val.children.length > 0 ?
                                        val.children.map((val) => {
                                            return {
                                                deviceCode: val.variableCoding,
                                                deviceName: val.variableName,
                                                id: val.id,
                                            }
                                        }) : val.children,
                                })
                                // }
                            })
                        } else {
                            ElMessage.error(requset.msg)
                        }
                    })
            } else {
                state.deviceList = []
            }

        },
        /**
         * @公共按钮权限
         * @param {*} state 
         */
        async getAuthorities(state, aa) {
            await api
                .getAuthorities({ menuName: aa })
                .then((requset) => {
                    if (requset.status === 'SUCCESS') {
                        state.authorities = []
                        var menuObj = requset.data;
                        menuObj.forEach(function (item) {
                            state.authorities.push(item.menuName)
                        })
                        // console.log(state.authorities)
                    } else {
                        ElMessage.error(requset.msg)
                    }
                })

        },
        /**
         * @公共api请求参数siteId
         * @param {*}} state 
         * @param {*} val 
         */
        increment(state, val) {
            state.siteId = val
        },
        /**
         * @公共处理时区方法
         */
        TimeAll_function(state, time) {
            if (time == '' || time == null || time == undefined) return

            // 清空原有数据
            state.Time_Data = [];

            // 遍历时间数组，格式化每个时间对象
            time.forEach(date => {
                // 使用dayjs解析Date对象并格式化为"YYYY-MM-DD HH:mm:ss"
                const formattedTime = dayjs(date).format('YYYY-MM-DD HH:mm:ss');
                state.Time_Data.push(formattedTime);
            });
        },
        /**
         * @公共处理开始时间和结束时间中的时间段天数
         * @param {*} state 
         * @param {*} begin 开始时间和结束时间
         */
        getAll(state, begin) {
            // 解析开始和结束日期（begin格式为["YYYY-MM-DD", "YYYY-MM-DD"]）
            const start = dayjs(begin[0]);
            const end = dayjs(begin[1]);

            // 生成日期数组
            const arrTime = [];
            let current = start;

            // 循环添加每天日期，直到超过结束日期
            while (current.isBefore(end) || current.isSame(end)) {
                // 直接格式化为"YY-MM-DD"（dayjs的YY是两位数年份，YYYY是四位数）
                arrTime.push(current.format('YY-MM-DD'));
                // 增加一天
                current = current.add(1, 'day');
            }

            state.timearr = arrTime;
        },
        /**
         * @公共echarts图表下载
         */
        getConnectedDataURL(state, refs) {
            state || refs
            var url = refs[0].getConnectedDataURL({
                pixelRatio: 15,
                backgroundColor: "black",
                excludeComponents: ["toolbox"],
                type: "png",
            });
            var $a = document.createElement("a");
            var type = "png";
            //图片名称
            $a.download = refs[1] + "." + type;
            $a.target = "_blank";
            $a.href = url;
            if (typeof MouseEvent === "function") {
                var evt = new MouseEvent("click", {
                    view: window,
                    bubbles: true,
                    cancelable: false,
                });
                $a.dispatchEvent(evt);
            }
        },
        /**
         * @公共时间 返回数组 -> 年月日时分秒 时间戳
         */
        getTimeAll(state) {
            const time = new Date();
            const Y = time.getFullYear(); //年
            const M = time.getMonth(); //月
            const D = time.getDate(); //日
            const HH = time.getHours(); //时，
            const MM = time.getMinutes(); //分
            const SS = time.getSeconds(); //秒
            const timestamp = new Date().getTime(); //时间戳
            state.Time_All = [Y, M, D, HH, MM, SS, timestamp]
            state.se_defaultTime = [new Date(Y, M, D, 0, 0, 0), new Date()] //设备监控--->历史趋势时间选择器v-model  //home设备总数
            state.th_defaultTime = [new Date(Y, M, D, 0, 0, 0), new Date()] //设备监控--->数据报表时间选择器v-model  //home运维管理
            state.fh_defaultTime = [new Date(Y, M, 1, 0, 0, 0), new Date()] //设备监控--->运行状态统计时间选择器v-model  //概览 -> 告警统计折线图
        },
        /**
         * @处理公共时间搓 返回数组 -> 年月日时分秒 时间戳
         */
        getTimestampAll(state, timestamp) {
            // 直接使用dayjs解析时间戳并格式化为 "YYYY-MM-DD HH:mm:ss"
            state.timeProcessing = dayjs(timestamp).format('YYYY-MM-DD HH:mm:ss');
        },
        /**
         * @公共获取某月的第一天和最后一天
         */
        getCurrentMonthLast(state, timeAll) {
            // 将传入的时间转换为dayjs对象
            const date = dayjs(timeAll);
            // 获取当月第一天，格式化为YYYY-MM-DD
            const firstDay = date.startOf('month').format('YYYY-MM-DD');
            // 获取当月最后一天，格式化为YYYY-MM-DD
            const lastDay = date.endOf('month').format('YYYY-MM-DD');
            // 赋值给状态
            state.monthList = [firstDay, lastDay];
        },
        /**
         * @获取当天日期
         */
        getNowFormatDate(state, timeAll) {
            // 直接使用dayjs处理日期并格式化为"YYYY-MM-DD"
            state.dateList = dayjs(timeAll).format('YYYY-MM-DD');
        }
    }
})